@@ -684,6 +684,9 @@ class Callable(Node):
         self.throws = not not throws
         self.instance_parameter = None  # Parameter
         self.parent = None  # A Class or Interface
+        self.finish_func = None
+        self.sync_func = None
+        self.async_func = None
 
     def _get_retval(self):
         return self._retval
@@ -755,6 +758,7 @@ class Function(Callable):
         self.internal_skipped = False   # if True, this func will not be written to GIR
         self.set_property = None        # Property name
         self.get_property = None        # Property name
+        self.is_inline = False
 
     def clone(self):
         clone = copy.copy(self)
