@@ -42,6 +42,9 @@ void gi_marshalling_tests_boolean_out_true (gboolean *v);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_boolean_out_false (gboolean *v);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_boolean_out_uninitialized (gboolean *v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_boolean_inout_true_false (gboolean *v);
@@ -72,6 +75,9 @@ void gi_marshalling_tests_int8_out_max (gint8 *v);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_int8_out_min (gint8 *v);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_int8_out_uninitialized (gint8 *v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_int8_inout_max_min (gint8 *v);
@@ -92,6 +98,9 @@ void gi_marshalling_tests_uint8_in (guint8 v);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_uint8_out (guint8 *v);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_uint8_out_uninitialized (guint8 *v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_uint8_inout (guint8 *v);
 
@@ -116,6 +125,9 @@ void gi_marshalling_tests_int16_out_max (gint16 *v);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_int16_out_min (gint16 *v);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_int16_out_uninitialized (gint16 *v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_int16_inout_max_min (gint16 *v);
@@ -136,6 +148,9 @@ void gi_marshalling_tests_uint16_in (guint16 v);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_uint16_out (guint16 *v);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_uint16_out_uninitialized (guint16 *v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_uint16_inout (guint16 *v);
 
@@ -161,6 +176,9 @@ void gi_marshalling_tests_int32_out_max (gint32 *v);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_int32_out_min (gint32 *v);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_int32_out_uninitialized (gint32 *v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_int32_inout_max_min (gint32 *v);
@@ -181,6 +199,9 @@ void gi_marshalling_tests_uint32_in (guint32 v);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_uint32_out (guint32 *v);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_uint32_out_uninitialized (guint32 *v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_uint32_inout (guint32 *v);
 
@@ -206,6 +227,9 @@ void gi_marshalling_tests_int64_out_max (gint64 *v);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_int64_out_min (gint64 *v);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_int64_out_uninitialized (gint64 *v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_int64_inout_max_min (gint64 *v);
@@ -226,6 +250,9 @@ void gi_marshalling_tests_uint64_in (guint64 v);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_uint64_out (guint64 *v);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_uint64_out_uninitialized (guint64 *v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_uint64_inout (guint64 *v);
 
@@ -251,6 +278,9 @@ void gi_marshalling_tests_short_out_max (gshort *short_);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_short_out_min (gshort *short_);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_short_out_uninitialized (gshort *v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_short_inout_max_min (gshort *short_);
@@ -271,6 +301,9 @@ void gi_marshalling_tests_ushort_in (gushort ushort_);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_ushort_out (gushort *ushort_);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_ushort_out_uninitialized (gushort *v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_ushort_inout (gushort *ushort_);
 
@@ -296,6 +329,9 @@ void gi_marshalling_tests_int_out_max (gint *int_);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_int_out_min (gint *int_);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_int_out_uninitialized (gint *v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_int_inout_max_min (gint *int_);
@@ -315,6 +351,9 @@ void gi_marshalling_tests_uint_in (guint uint_);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_uint_out (guint *uint_);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_uint_out_uninitialized (guint *v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_uint_inout (guint *uint_);
 
@@ -339,6 +378,9 @@ void gi_marshalling_tests_long_out_max (glong *long_);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_long_out_min (glong *long_);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_long_out_uninitialized (glong *v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_long_inout_max_min (glong *long_);
@@ -361,6 +403,9 @@ void gi_marshalling_tests_ulong_out (gulong *ulong_);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_ulong_inout (gulong *ulong_);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_ulong_out_uninitialized (gulong *v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 gssize gi_marshalling_tests_ssize_return_max (void);
@@ -382,6 +427,9 @@ void gi_marshalling_tests_ssize_out_max (gssize *ssize);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_ssize_out_min (gssize *ssize);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_ssize_out_uninitialized (gssize *v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_ssize_inout_max_min (gssize *ssize);
@@ -402,6 +450,9 @@ void gi_marshalling_tests_size_in (gsize size);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_size_out (gsize *size);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_size_out_uninitialized (gsize *v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_size_inout (gsize *size);
 
@@ -419,6 +470,12 @@ void gi_marshalling_tests_float_in (gfloat v);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_float_out (gfloat *v);
 
+_GI_TEST_EXTERN
+void gi_marshalling_tests_float_noncanonical_nan_out (gfloat *v);
+
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_float_out_uninitialized (gfloat *v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_float_inout (gfloat *v);
@@ -436,6 +493,12 @@ void gi_marshalling_tests_double_in (gdouble v);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_double_out (gdouble *v);
 
+_GI_TEST_EXTERN
+void gi_marshalling_tests_double_noncanonical_nan_out (gdouble *v);
+
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_double_out_uninitialized (gdouble *v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_double_inout (gdouble *v);
@@ -454,6 +517,9 @@ void gi_marshalling_tests_time_t_in (time_t v);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_time_t_out (time_t *v);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_time_t_out_uninitialized (time_t *v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_time_t_inout (time_t *v);
@@ -480,6 +546,9 @@ void gi_marshalling_tests_gtype_string_in (GType gtype);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gtype_out (GType *gtype);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_gtype_out_uninitialized (GType *v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gtype_string_out (GType *gtype);
@@ -508,6 +577,9 @@ void gi_marshalling_tests_utf8_full_in (gchar *utf8);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_utf8_none_out (const gchar **utf8);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_utf8_none_out_uninitialized (const gchar **v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_utf8_full_out (gchar **utf8);
 
@@ -559,6 +631,9 @@ void gi_marshalling_tests_enum_in (GIMarshallingTestsEnum v);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_enum_out (GIMarshallingTestsEnum *v);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_enum_out_uninitialized (GIMarshallingTestsEnum **v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_enum_inout (GIMarshallingTestsEnum *v);
@@ -589,6 +664,9 @@ void gi_marshalling_tests_genum_in (GIMarshallingTestsGEnum v);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_genum_out (GIMarshallingTestsGEnum *v);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_genum_out_uninitialized (GIMarshallingTestsGEnum *v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_genum_inout (GIMarshallingTestsGEnum *v);
@@ -625,6 +703,9 @@ void gi_marshalling_tests_flags_in_zero (GIMarshallingTestsFlags v);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_flags_out (GIMarshallingTestsFlags *v);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_flags_out_uninitialized (GIMarshallingTestsFlags *v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_flags_inout (GIMarshallingTestsFlags *v);
@@ -656,6 +737,9 @@ void gi_marshalling_tests_no_type_flags_in_zero (GIMarshallingTestsNoTypeFlags v
 _GI_TEST_EXTERN
 void gi_marshalling_tests_no_type_flags_out (GIMarshallingTestsNoTypeFlags *v);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_no_type_flags_out_uninitialized (GIMarshallingTestsNoTypeFlags **v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_no_type_flags_inout (GIMarshallingTestsNoTypeFlags *v);
@@ -678,6 +762,9 @@ const gshort *gi_marshalling_tests_array_fixed_short_return (void);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_array_fixed_int_in (const gint *ints);
 
+_GI_TEST_EXTERN
+void gi_marshalling_tests_array_fixed_caller_allocated_out (gint *ints);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_array_fixed_short_in (const gshort *shorts);
 
@@ -685,10 +772,19 @@ void gi_marshalling_tests_array_fixed_short_in (const gshort *shorts);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_array_fixed_out (gint **ints);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_array_fixed_out_uninitialized (gint **v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_array_fixed_out_struct (GIMarshallingTestsSimpleStruct **structs);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_array_fixed_out_struct_uninitialized (GIMarshallingTestsSimpleStruct **v G_GNUC_UNUSED);
+
+_GI_TEST_EXTERN
+void gi_marshalling_tests_array_fixed_caller_allocated_struct_out (GIMarshallingTestsSimpleStruct *structs);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_array_fixed_inout (gint **ints);
@@ -761,6 +857,9 @@ void gi_marshalling_tests_array_in_guint8_len (const gint *ints, guint8 length);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_array_out (gint **ints, gint *length);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_array_out_uninitialized (gint **v G_GNUC_UNUSED, gint *length G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_array_out_etc (gint first, gint **ints, gint *length, gint last, gint *sum);
 
@@ -803,6 +902,9 @@ void gi_marshalling_tests_array_zero_terminated_in (gchar **utf8s);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_array_zero_terminated_out (const gchar ***utf8s);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_array_zero_terminated_out_uninitialized (const gchar ***v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_array_zero_terminated_inout (const gchar ***utf8s);
@@ -854,12 +956,21 @@ void gi_marshalling_tests_garray_utf8_none_in (GArray *array_);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_garray_utf8_none_out (GArray **array_);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_garray_utf8_none_out_uninitialized (GArray **v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_garray_utf8_container_out (GArray **array_);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_garray_utf8_container_out_uninitialized (GArray **v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_garray_utf8_full_out (GArray **array_);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_garray_utf8_full_out_uninitialized (GArray **v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_garray_utf8_full_out_caller_allocated (GArray *array_);
 
@@ -901,12 +1012,21 @@ void gi_marshalling_tests_gptrarray_utf8_none_in (GPtrArray *parray_);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gptrarray_utf8_none_out (GPtrArray **parray_);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_gptrarray_utf8_none_out_uninitialized (GPtrArray **v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gptrarray_utf8_container_out (GPtrArray **parray_);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_gptrarray_utf8_container_out_uninitialized (GPtrArray **v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gptrarray_utf8_full_out (GPtrArray **parray_);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_gptrarray_utf8_full_out_uninitialized (GPtrArray **v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gptrarray_utf8_none_inout (GPtrArray **parray_);
@@ -944,6 +1064,9 @@ void gi_marshalling_tests_gstrv_in (GStrv g_strv);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gstrv_out (GStrv *g_strv);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_gstrv_out_uninitialized (GStrv *v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gstrv_inout (GStrv *g_strv);
 
@@ -978,12 +1101,21 @@ void gi_marshalling_tests_glist_utf8_none_in (GList *list);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_glist_utf8_none_out (GList **list);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_glist_utf8_none_out_uninitialized (GList **v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_glist_utf8_container_out (GList **list);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_glist_utf8_container_out_uninitialized (GList **v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_glist_utf8_full_out (GList **list);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_glist_utf8_full_out_uninitialized (GList **v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_glist_utf8_none_inout (GList **list);
@@ -1020,12 +1152,21 @@ void gi_marshalling_tests_gslist_utf8_none_in (GSList *list);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gslist_utf8_none_out (GSList **list);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_gslist_utf8_none_out_uninitialized (GSList **v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gslist_utf8_container_out (GSList **list);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_gslist_utf8_container_out_uninitialized (GSList **v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gslist_utf8_full_out (GSList **list);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_gslist_utf8_full_out_uninitialized (GSList **v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gslist_utf8_none_inout (GSList **list);
@@ -1081,12 +1222,21 @@ void gi_marshalling_tests_ghashtable_utf8_full_in (GHashTable *hash_table);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_ghashtable_utf8_none_out (GHashTable **hash_table);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_ghashtable_utf8_none_out_uninitialized (GHashTable **v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_ghashtable_utf8_container_out (GHashTable **hash_table);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_ghashtable_utf8_container_out_uninitialized (GHashTable **v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_ghashtable_utf8_full_out (GHashTable **hash_table);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_ghashtable_utf8_full_out_uninitialized (GHashTable **v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_ghashtable_utf8_none_inout (GHashTable **hash_table);
@@ -1103,6 +1253,11 @@ void gi_marshalling_tests_ghashtable_utf8_full_inout (GHashTable **hash_table);
 _GI_TEST_EXTERN
 GValue *gi_marshalling_tests_gvalue_return (void);
 
+_GI_TEST_EXTERN
+GValue *gi_marshalling_tests_gvalue_noncanonical_nan_float (void);
+
+_GI_TEST_EXTERN
+GValue *gi_marshalling_tests_gvalue_noncanonical_nan_double (void);
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gvalue_in (GValue *value);
@@ -1127,6 +1282,9 @@ void gi_marshalling_tests_gvalue_in_flags (GValue *value);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gvalue_out (GValue **value);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_gvalue_out_uninitialized (GValue **v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gvalue_int64_out (GValue **value);
 
@@ -1146,6 +1304,14 @@ void gi_marshalling_tests_gvalue_flat_array (guint         n_values,
 _GI_TEST_EXTERN
 GValue *gi_marshalling_tests_return_gvalue_flat_array (void);
 
+_GI_TEST_EXTERN
+GValue *gi_marshalling_tests_return_gvalue_zero_terminated_array (void);
+
+_GI_TEST_EXTERN
+GValue *gi_marshalling_tests_gvalue_round_trip (GValue *value);
+
+_GI_TEST_EXTERN
+GValue *gi_marshalling_tests_gvalue_copy (GValue *value);
 
 _GI_TEST_EXTERN
 GValue *gi_marshalling_tests_gvalue_flat_array_round_trip (const GValue one,
@@ -1307,6 +1473,9 @@ void gi_marshalling_tests_boxed_struct_inv (GIMarshallingTestsBoxedStruct *struc
 _GI_TEST_EXTERN
 void gi_marshalling_tests_boxed_struct_out (GIMarshallingTestsBoxedStruct **struct_);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_boxed_struct_out_uninitialized (GIMarshallingTestsBoxedStruct **v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_boxed_struct_inout (GIMarshallingTestsBoxedStruct **struct_);
@@ -1315,6 +1484,12 @@ typedef union {
     glong long_;
 } GIMarshallingTestsUnion;
 
+typedef union {
+    glong long_;
+    gsize size;
+    const gchar *str;
+} GIMarshallingTestsUnregisteredUnion;
+
 
 _GI_TEST_EXTERN
 GType gi_marshalling_tests_union_get_type (void) G_GNUC_CONST;
@@ -1331,6 +1506,79 @@ void gi_marshalling_tests_union_inv (GIMarshallingTestsUnion *union_);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_union_method (GIMarshallingTestsUnion *union_);
 
+typedef enum
+{
+  GI_MARSHALLING_TESTS_STRUCTURED_UNION_TYPE_NONE,
+  GI_MARSHALLING_TESTS_STRUCTURED_UNION_TYPE_SIMPLE_STRUCT,
+  GI_MARSHALLING_TESTS_STRUCTURED_UNION_TYPE_NESTED_STRUCT,
+  GI_MARSHALLING_TESTS_STRUCTURED_UNION_TYPE_POINTER_STRUCT,
+  GI_MARSHALLING_TESTS_STRUCTURED_UNION_TYPE_BOXED_STRUCT,
+  GI_MARSHALLING_TESTS_STRUCTURED_UNION_TYPE_BOXED_STRUCT_PTR,
+  GI_MARSHALLING_TESTS_STRUCTURED_UNION_TYPE_SINGLE_UNION,
+} GIMarshallingTestsStructuredUnionType;
+
+typedef struct {
+    GIMarshallingTestsStructuredUnionType type;
+    GIMarshallingTestsSimpleStruct parent;
+} GIMarshallingTestsStructuredUnionSimpleStruct;
+
+typedef struct {
+    GIMarshallingTestsStructuredUnionType type;
+    GIMarshallingTestsNestedStruct parent;
+} GIMarshallingTestsStructuredUnionNestedStruct;
+
+typedef struct {
+    GIMarshallingTestsStructuredUnionType type;
+    GIMarshallingTestsPointerStruct parent;
+} GIMarshallingTestsStructuredUnionPointerStruct;
+
+typedef struct {
+    GIMarshallingTestsStructuredUnionType type;
+    GIMarshallingTestsBoxedStruct parent;
+} GIMarshallingTestsStructuredUnionBoxedStruct;
+
+typedef struct {
+    GIMarshallingTestsStructuredUnionType type;
+    GIMarshallingTestsBoxedStruct *parent;
+} GIMarshallingTestsStructuredUnionBoxedStructPtr;
+
+typedef struct {
+    GIMarshallingTestsStructuredUnionType type;
+    GIMarshallingTestsUnion union_;
+} GIMarshallingTestsStructuredUnionUnionStruct;
+
+typedef union {
+    GIMarshallingTestsStructuredUnionUnionStruct parent;
+} GIMarshallingTestsStructuredUnionSingleUnion;
+
+typedef union {
+    /*< private >*/
+    GIMarshallingTestsStructuredUnionType type;
+
+    GIMarshallingTestsStructuredUnionSimpleStruct simple_struct;
+    GIMarshallingTestsStructuredUnionNestedStruct nested_struct;
+    GIMarshallingTestsStructuredUnionPointerStruct pointer_struct;
+    GIMarshallingTestsStructuredUnionBoxedStruct boxed_struct;
+    GIMarshallingTestsStructuredUnionBoxedStructPtr boxed_struct_ptr;
+    GIMarshallingTestsStructuredUnionSingleUnion single_union;
+} GIMarshallingTestsStructuredUnion;
+
+_GI_TEST_EXTERN
+GType gi_marshalling_tests_structured_union_get_type (void) G_GNUC_CONST;
+
+_GI_TEST_EXTERN
+GIMarshallingTestsStructuredUnion *gi_marshalling_tests_structured_union_new (GIMarshallingTestsStructuredUnionType type);
+
+/* we want this to clash with a field value name */
+_GI_TEST_EXTERN
+GIMarshallingTestsStructuredUnionType gi_marshalling_tests_structured_union_type (GIMarshallingTestsStructuredUnion *structured_union);
+
+typedef union {
+    GIMarshallingTestsStructuredUnionType type;
+    GIMarshallingTestsStructuredUnionSimpleStruct simple_struct1;
+    GIMarshallingTestsStructuredUnionSimpleStruct simple_struct2;
+} GIMarshallingTestsStructuredUnionSingleType;
+
  /* Object */
 
 #define GI_MARSHALLING_TESTS_TYPE_OBJECT             (gi_marshalling_tests_object_get_type ())
@@ -1363,7 +1611,7 @@ struct _GIMarshallingTestsObjectClass
 
     /**
      * GIMarshallingTestsObjectClass::method_int8_arg_and_out_caller:
-     * @out: (out caller-allocates):
+     * @out: (out):
      */
     void (* method_int8_arg_and_out_caller) (GIMarshallingTestsObject *self, gint8 arg, gint8 *out);
 
@@ -1375,7 +1623,7 @@ struct _GIMarshallingTestsObjectClass
 
     /**
      * GIMarshallingTestsObjectClass::method_str_arg_out_ret:
-     * @out: (out caller-allocates):
+     * @out: (out):
      *
      * Returns: (transfer none)
      */
@@ -1680,9 +1928,15 @@ void gi_marshalling_tests_object_full_in (GIMarshallingTestsObject *object);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_object_none_out (GIMarshallingTestsObject **object);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_object_none_out_uninitialized (GIMarshallingTestsObject **v G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_object_full_out (GIMarshallingTestsObject **object);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_object_full_out_uninitialized (GIMarshallingTestsObject **v G_GNUC_UNUSED);
+
 
 _GI_TEST_EXTERN
 void gi_marshalling_tests_object_none_inout (GIMarshallingTestsObject **object);
@@ -1922,9 +2176,15 @@ void gi_marshalling_tests_gerror_array_in(gint *in_ints, GError **error);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gerror_out(GError **error, gchar **debug);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_gerror_out_uninitialized (GError **v G_GNUC_UNUSED, gchar **v2 G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 void gi_marshalling_tests_gerror_out_transfer_none(GError **err, const gchar **debug);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_gerror_out_transfer_none_uninitialized (GError **v G_GNUC_UNUSED, const gchar **v2 G_GNUC_UNUSED);
+
 _GI_TEST_EXTERN
 GError *gi_marshalling_tests_gerror_return(void);
 
@@ -1938,6 +2198,9 @@ GParamSpec *gi_marshalling_tests_param_spec_return (void);
 _GI_TEST_EXTERN
 void gi_marshalling_tests_param_spec_out(GParamSpec **param);
 
+_GI_TEST_EXTERN
+gboolean gi_marshalling_tests_param_spec_out_uninitialized (GParamSpec **v G_GNUC_UNUSED);
+
 /* Overrides */
 
 #define GI_MARSHALLING_TESTS_OVERRIDES_CONSTANT 42
@@ -2026,6 +2289,7 @@ struct _GIMarshallingTestsPropertiesObject {
     guint64 some_uint64;
     gfloat some_float;
     gdouble some_double;
+    gchar *some_string;
     gchar **some_strv;
     GIMarshallingTestsBoxedStruct* some_boxed_struct;
     GList* some_boxed_glist;
@@ -2049,4 +2313,65 @@ GType gi_marshalling_tests_properties_object_get_type (void) G_GNUC_CONST;
 _GI_TEST_EXTERN
 GIMarshallingTestsPropertiesObject *gi_marshalling_tests_properties_object_new (void);
 
+/* Signals object */
+
+#define GI_MARSHALLING_TESTS_TYPE_SIGNALS_OBJECT (gi_marshalling_tests_signals_object_get_type ())
+#define GI_MARSHALLING_TESTS_SIGNALS_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GI_MARSHALLING_TESTS_TYPE_SIGNALS_OBJECT, GIMarshallingTestsSignalsObject))
+#define GI_MARSHALLING_TESTS_SIGNALS_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GI_MARSHALLING_TESTS_TYPE_SIGNALS_OBJECT, GIMarshallingTestsSignalsObjectClass))
+#define GI_MARSHALLING_TESTS_IS_SIGNALS_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GI_MARSHALLING_TESTS_TYPE_SIGNALS_OBJECT))
+#define GI_MARSHALLING_TESTS_IS_SIGNALS_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GI_MARSHALLING_TESTS_TYPE_SIGNALS_OBJECT))
+#define GI_MARSHALLING_TESTS_SIGNALS_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GI_MARSHALLING_TESTS_TYPE_SIGNALS_OBJECT, GIMarshallingTestsSignalsObjectClass))
+
+typedef struct _GIMarshallingTestsSignalsObject GIMarshallingTestsSignalsObject;
+typedef struct _GIMarshallingTestsSignalsObjectClass GIMarshallingTestsSignalsObjectClass;
+
+struct _GIMarshallingTestsSignalsObject {
+    GObject parent_instance;
+};
+
+struct _GIMarshallingTestsSignalsObjectClass {
+    GObjectClass parent_class;
+};
+
+
+_GI_TEST_EXTERN
+GType gi_marshalling_tests_signals_object_get_type (void) G_GNUC_CONST;
+
+
+_GI_TEST_EXTERN
+GIMarshallingTestsSignalsObject *gi_marshalling_tests_signals_object_new (void);
+
+_GI_TEST_EXTERN
+void gi_marshalling_tests_signals_object_emit_boxed_gptrarray_utf8 (GIMarshallingTestsSignalsObject *object);
+
+_GI_TEST_EXTERN
+void gi_marshalling_tests_signals_object_emit_boxed_gptrarray_utf8_container (GIMarshallingTestsSignalsObject *object);
+
+_GI_TEST_EXTERN
+void gi_marshalling_tests_signals_object_emit_boxed_gptrarray_utf8_full (GIMarshallingTestsSignalsObject *object);
+
+_GI_TEST_EXTERN
+void gi_marshalling_tests_signals_object_emit_boxed_gptrarray_boxed_struct (GIMarshallingTestsSignalsObject *object);
+
+_GI_TEST_EXTERN
+void gi_marshalling_tests_signals_object_emit_boxed_gptrarray_boxed_struct_container (GIMarshallingTestsSignalsObject *object);
+
+_GI_TEST_EXTERN
+void gi_marshalling_tests_signals_object_emit_boxed_gptrarray_boxed_struct_full (GIMarshallingTestsSignalsObject *object);
+
+_GI_TEST_EXTERN
+void gi_marshalling_tests_signals_object_emit_hash_table_utf8_int (GIMarshallingTestsSignalsObject *object);
+
+_GI_TEST_EXTERN
+void gi_marshalling_tests_signals_object_emit_hash_table_utf8_int_container (GIMarshallingTestsSignalsObject *object);
+
+_GI_TEST_EXTERN
+void gi_marshalling_tests_signals_object_emit_hash_table_utf8_int_full (GIMarshallingTestsSignalsObject *object);
+
+_GI_TEST_EXTERN
+void gi_marshalling_tests_signals_object_emit_boxed_struct (GIMarshallingTestsSignalsObject *object);
+
+_GI_TEST_EXTERN
+void gi_marshalling_tests_signals_object_emit_boxed_struct_full (GIMarshallingTestsSignalsObject *object);
+
 #endif /* _GI_MARSHALLING_TESTS_H_ */
